# Claude research notes (versioned)

This folder contains **versioned research notes** about Claude capabilities/skills (distinct from the shareable Agent
Skills `SKILL.md` ecosystem).

Related:
- Agent Skills (shareable `SKILL.md`) notes live in `docs/skills/`
- Agent Skills integration proposal: `docs/guide/agent-skills.md`

Files:
- `docs/claude/claude-skills-overview.md`
- `docs/claude/claude-skills-top-20.md`
- `docs/claude/claude-skills-sources.md`
- `docs/claude/abstractframework-fit.md`

